import { UseSignInData } from '@farcaster/auth-kit';
import { CrossmintAuth, AuthMaterialWithUser, OAuthProvider, CrossmintAuthOptions } from '@crossmint/common-sdk-auth';
import { Crossmint } from '@crossmint/common-sdk-base';

type CrossmintAuthClientConfig = CrossmintAuthOptions & {
    callbacks?: CrossmintAuthClientCallbacks;
    logoutRoute?: string;
};
declare class CrossmintAuthClient extends CrossmintAuth {
    private callbacks;
    private refreshTask;
    private refreshPromise;
    private logoutRoute;
    private constructor();
    static from(crossmint: Crossmint, config?: CrossmintAuthClientConfig): CrossmintAuthClient;
    getUser(): Promise<any>;
    storeAuthMaterial(authMaterial: AuthMaterialWithUser): void;
    logout(): Promise<void>;
    handleRefreshAuthMaterial(refreshTokenSecret?: string): Promise<void>;
    getOAuthUrl(provider: OAuthProvider): Promise<any>;
    sendEmailOtp(email: string): Promise<any>;
    confirmEmailOtp(email: string, emailId: string, token: string): Promise<any>;
    signInWithFarcaster(data: UseSignInData): Promise<any>;
    signInWithSmartWallet(address: string): Promise<any>;
    authenticateSmartWallet(address: string, signature: string): Promise<any>;
    private logoutFromCustomRoute;
    private scheduleNextRefresh;
    private cancelScheduledRefresh;
}
type CrossmintAuthClientCallbacks = {
    onTokenRefresh?: (authMaterial: AuthMaterialWithUser) => void;
    onLogout?: () => void;
};

export { CrossmintAuthClient };
